@@ -155,6 +155,7 @@ nitpick_ignore = [
 # Intersphinx settings
 intersphinx_mapping = {
     "attrs": ("https://www.attrs.org/en/stable", None),
+    "compwa-org": ("https://compwa-org.readthedocs.io", None),
     "expertsystem": ("https://expertsystem.readthedocs.io/en/stable", None),
     "ipywidgets": ("https://ipywidgets.readthedocs.io/en/stable", None),
     "matplotlib": ("https://matplotlib.org/stable/", None),
@@ -226,13 +227,10 @@ myst_enable_extensions = [
 BINDER_LINK = (
     f"https://mybinder.org/v2/gh/ComPWA/{repo_name}/stable?filepath=docs/usage"
 )
-COLAB_LINK = (
-    f"https://colab.research.google.com/github/ComPWA/{repo_name}/blob/stable"
-)
 myst_substitutions = {
     "run_interactive": f"""
 ```{{margin}}
-Run this notebook in [Google Colab]({COLAB_LINK}), [Binder]({BINDER_LINK}), or
+Run this notebook [on Binder]({BINDER_LINK}) or
 {{ref}}`locally on Jupyter Lab <pwa:develop:Jupyter Notebooks>` to
 interactively modify the parameters.
 ```
